@@ -37,6 +37,7 @@ class Step:
         self.env = dict(os.environ, **parameters['env']) if "env" in parameters else os.environ
         self.pause_message = None if "manual_pause_message" not in parameters else parameters["manual_pause_message"]
         self.match_mode = 'exact' if "output_match_mode" not in parameters else parameters["output_match_mode"]
+        self.tags = [] if "tags" not in parameters else parameters["tags"]
         self.shell = shell
 
         if self.match_mode not in VALID_MATCH_MODES:
@@ -104,7 +105,9 @@ class Step:
                     color = 'yellow'
                 elif c.return_code != self.expect_return_code:
                     color = 'red'
-                report += "\tcommand: `{}`\n\treturn_code: {}\n".format(c.command, colored(c.return_code, color))
+                report += f"\tcommand: `{c.command}`\n"
+                report += f"\treturn_code: {colored(c.return_code, color)}\n"
+                report += f"\tduration_seconds: {c.duration_seconds:.{3}}\n"
 
         for out in 'stdout', 'stderr':
             report += "\tExpected {} (output_match_mode: {}):\n".format(out, self.match_mode)
